
#import <Foundation/Foundation.h>
#import "iCore.h"

@class B4I;

//~Shortname:Store
//~Version:1.10
//~dependson:StoreKit.framework
//~event:PurchaseCompleted (Success As Boolean, Product As Purchase)
//~event:InformationAvailable (Success As Boolean, Products As List)
//~event:TransactionsRestored (Success As Boolean)
/**
* The Store object provides access to Apple's in app purchases features. See the forum tutorial for more information.
*/
@interface B4IStore : NSObject
//Checks whether the device supports in app purchases (it might be restricted).
@property (readonly, nonatomic)BOOL CanMakePayments;
//Initializes the object and sets the subs that will handle the events. You should initialize and use a single Store instance.
- (void)Initialize:(B4I *)bi :(NSString *)EventName;

- (void)RequestProductsInformation:(B4IList *)Ids;

/**
* Starts a payment request process for the given product id. The user will be asked to log in and approve the purchase.
* The PurchaseCompleted event will later be raised.
*/
- (void)RequestPayment:(NSString *)ProductId;

/**
* Restores successful transactions of non-consumable products. The PurchaseCompleted will be raised for each transaction.
*Note that the user might be asked to log in to his account. You should not call this method when the app starts.
*Only when the user asks to restore previous transactions.
*The TransactionsRestored event will later be raised.
*/
- (void)RestoreTransactions;
@end
//~shortname:Purchase
//~objectwrapper: SKPaymentTransaction*
@interface B4IPurchase:B4IObjectWrapper
/**
* Returns the error object if the transaction was not successful.
*/
@property (nonatomic, readonly)B4IExceptionWrapper *Error;
//Returns the transaction date. Only relevant if the transaction was successful.
@property (nonatomic, readonly)long long TransactionDate;
//Returns the transaction unique identifier.
@property (nonatomic, readonly)NSString *TransactionIdentifier;
//Returns the product identifier.
@property (nonatomic, readonly)NSString *ProductIdentifier;
@end

//~shortname: ProductInformation
//~objectwrapper: SKProduct*
@interface B4IProductInformation:B4IObjectWrapper
//Returns the product identifier.
@property (nonatomic, readonly) NSString *ProductIdentifier;
//Returns the product title.
@property (nonatomic, readonly) NSString *Title;
//Returns the product description.
@property (nonatomic, readonly) NSString *Description;
//Returns the localized price string.
@property (nonatomic, readonly) NSString *LocalizedPrice;
@end
